Interpreter for the Lox programming language

# Getting Started

`pip install pplox`

Create your lox file. For example, `parentheses.lox` 

```
(()
```

Tokenize the file with `pplox --tokenize parentheses.lox`.
See the [documentation](https://pplox.readthedocs.io/en/latest/) for more details.